@@ -17,7 +17,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-auto-scroller.c 1623 2007-11-03 23:19:45Z cyrilbois $
  */
 
 /* this file is based on work of Daniel Erat for galeon 1 */
@@ -28,9 +27,7 @@
 #include "autoscroll.xpm.h"
 #include "ephy-debug.h"
 
-#include <gtk/gtkimage.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
 #include <math.h>
 #include <sys/time.h>
@@ -75,11 +72,12 @@ ephy_auto_scroller_set_window (EphyAutoScroller *scroller,
 			       EphyWindow *window)
 {
 	EphyAutoScrollerPrivate *priv = scroller->priv;
+	GtkWindowGroup *group;
 
 	priv->window = window;
+	group = gtk_window_get_group (GTK_WINDOW (priv->window));
 
-	gtk_window_group_add_window (GTK_WINDOW (priv->window)->group,
-				     GTK_WINDOW (priv->popup));
+	gtk_window_group_add_window (group, GTK_WINDOW (priv->popup));
 }
 
 static gboolean
@@ -187,6 +185,39 @@ ephy_auto_scroller_grab_notify_cb (GtkWidget *widget,
 	}
 }
 
+static void
+ephy_auto_scroller_scroll_pixels (EphyEmbed *embed, int scroll_x, int scroll_y)
+{
+	GtkAdjustment *adj;
+	gdouble value;
+	gdouble new_value;
+	gdouble page_size;
+	gdouble upper;
+	gdouble lower;
+	GtkWidget *sw;
+
+	sw = gtk_widget_get_parent (GTK_WIDGET (ephy_embed_get_web_view (embed)));
+	g_return_if_fail (GTK_IS_SCROLLED_WINDOW (sw));
+
+	adj = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (sw));
+	upper = gtk_adjustment_get_upper (adj);
+	lower = gtk_adjustment_get_lower (adj);
+	value = gtk_adjustment_get_value (adj);
+	page_size = gtk_adjustment_get_page_size (adj);
+
+	new_value = CLAMP (value + scroll_x, lower, upper - page_size);
+	gtk_adjustment_set_value (adj, new_value);
+
+	adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sw));
+	upper = gtk_adjustment_get_upper (adj);
+	lower = gtk_adjustment_get_lower (adj);
+	value = gtk_adjustment_get_value (adj);
+	page_size = gtk_adjustment_get_page_size (adj);
+
+	new_value = CLAMP (value + scroll_y, lower, upper - page_size);
+	gtk_adjustment_set_value (adj, new_value);
+}
+
 static int
 ephy_auto_scroller_timeout_cb (EphyAutoScroller *scroller)
 {
@@ -234,7 +265,7 @@ ephy_auto_scroller_timeout_cb (EphyAutoScroller *scroller)
 	/* do scrolling, moving at a constart speed regardless of the
 	 * scrolling delay */
 
-	ephy_embed_scroll_pixels (priv->embed, scroll_step_x_int, scroll_step_y_int);
+	ephy_auto_scroller_scroll_pixels (priv->embed, scroll_step_x_int, scroll_step_y_int);
 
 	/* find out how long the scroll took */
 	gettimeofday (&finish_time, NULL);
@@ -269,8 +300,8 @@ ephy_auto_scroller_timeout_cb (EphyAutoScroller *scroller)
 void
 ephy_auto_scroller_start (EphyAutoScroller *scroller,
 			  EphyEmbed *embed,
-			  int x,
-			  int y)
+			  gdouble x,
+			  gdouble y)
 {
 	EphyAutoScrollerPrivate *priv = scroller->priv;
 	GtkWidget *widget, *child;
@@ -309,7 +340,7 @@ ephy_auto_scroller_start (EphyAutoScroller *scroller,
 	priv->roundoff_error_y = 0;
 
 	g_signal_connect (priv->window, "motion-notify-event",
-			    G_CALLBACK (ephy_auto_scroller_motion_cb), scroller);
+			  G_CALLBACK (ephy_auto_scroller_motion_cb), scroller);
 	g_signal_connect (priv->window, "button-press-event",
 			  G_CALLBACK (ephy_auto_scroller_mouse_press_cb), scroller);
 	g_signal_connect (priv->window, "key-press-event",
