@@ -22,7 +22,6 @@
 
 #include "ephy-select-stylesheet-extension.h"
 #include "ephy-css-menu.h"
-#include "mozilla-helpers.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
@@ -35,9 +34,6 @@ register_module (GTypeModule *module)
 {
 	LOG ("Registering EphySelectStylesheetExtension");
 
-        if (!mozilla_glue_startup ())
-              return 0;
-
 #ifdef ENABLE_NLS
 	/* Initialize the i18n stuff */
 	bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
