@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks-extension.c 1641 2007-11-17 12:47:10Z cyrilbois $
+ *  $Id$
  */
 
 #include "config.h"
@@ -23,24 +23,13 @@
 #include "smart-bookmarks-extension.h"
 #include "mozilla-selection.h"
 
-#include <epiphany/ephy-extension.h>
-#include <epiphany/ephy-embed.h>
-#include <epiphany/ephy-embed-container.h>
-#include <epiphany/ephy-command-manager.h>
-#include <epiphany/ephy-shell.h>
-#include <epiphany/ephy-session.h>
-#include <epiphany/ephy-node.h>
-#include <epiphany/ephy-bookmarks.h>
+#include <epiphany/epiphany.h>
 
 #include "eel-gconf-extensions.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmenuitem.h>
+#include <gtk/gtk.h>
 
 #include <glib/gi18n-lib.h>
 
